@@ -4,7 +4,7 @@ use 5.006;
 use strict;
 use warnings;
 use Carp;
-our $VERSION = '0.9.10';
+our $VERSION = '0.9.11';
 
 print __PACKAGE__.' is version: '.$VERSION.$/ if($ENV{'PDF_TABLE_DEBUG'});
 
@@ -278,6 +278,53 @@ sub table
         carp "Error: Mandatory parameter is missing pdf/page/data object!\n";
         return;
     }
+
+    # Validate mandatory argument data type
+    croak "Error: Invalid pdf object received."  unless (ref($pdf) eq 'PDF::API2');
+    croak "Error: Invalid page object received." unless (ref($page) eq 'PDF::API2::Page');
+    croak "Error: Invalid data received."        unless ((ref($data) eq 'ARRAY') && scalar(@$data));
+    croak "Error: Missing required settings."    unless (scalar(keys %arg));
+
+    # Validate settings key
+    my %valid_settings_key = (
+	x                     => 1,
+        w                     => 1,
+        start_y               => 1,
+        start_h               => 1,
+        next_y                => 1,
+        next_h                => 1,
+        lead                  => 1,
+        padding               => 1,
+        padding_right         => 1,
+        padding_left          => 1,
+        padding_top           => 1,
+        padding_bottom        => 1,
+        background_color      => 1,
+        background_color_odd  => 1,
+        background_color_even => 1,
+        border                => 1,
+        border_color          => 1,
+        horizontal_borders    => 1,
+        vertical_borders      => 1,
+        font                  => 1,
+        font_size             => 1,
+        font_color            => 1,
+        font_color_even       => 1,
+        background_color_odd  => 1,
+        background_color_even => 1,
+        row_height            => 1,
+        new_page_func         => 1,
+        header_props          => 1,
+        column_props          => 1,
+        cell_props            => 1,
+        max_word_length       => 1,
+        cell_render_hook      => 1,
+    );
+    foreach my $key (keys %arg) {
+	croak "Error: Invalid setting key '$key' received." 
+            unless (exists $valid_settings_key{$key});
+    }
+
     # Try to provide backward compatibility
     foreach my $key (keys %arg)
     {
@@ -335,7 +382,7 @@ sub table
         $header_props->{'font_color'    } = $header_props->{'font_color'    } || '#000066';
         $header_props->{'font_size'     } = $header_props->{'font_size'     } || $fnt_size + 2;
         $header_props->{'bg_color'      } = $header_props->{'bg_color'      } || '#FFFFAA';
-        $header_props->{'justify'       } = $header_props->{'justify'       } || 'left';
+        $header_props->{'justify'       } = $header_props->{'justify'       };
     }
 
     my $header_row  = undef;
@@ -702,6 +749,21 @@ sub table
                         $do_leftovers = 1;
                     }
                 }
+                
+                # Hook to pass coordinates back - http://www.perlmonks.org/?node_id=754777
+                if (ref $arg{cell_render_hook} eq 'CODE') {
+                   $arg{cell_render_hook}->(
+                                            $page,
+                                            $first_row,
+                                            $row_index,
+                                            $column_idx,
+                                            $cur_x,
+                                            $cur_y-$row_h,
+                                            $calc_column_widths->[$column_idx],
+                                            $row_h
+                                           );    
+                }
+
                 $cur_x += $calc_column_widths->[$column_idx];
             }
             if( $do_leftovers )
@@ -956,7 +1018,7 @@ For full %settings description see section L</Table settings> below.
 
 This method will add more pages to the pdf instance as required based on the formatting options and the amount of data.
 
-=item Reuturns
+=item Returns
 
 The return value is a 3 items list where 
 
@@ -1149,11 +1211,28 @@ Don't forget that your function must return a page object created with PDF::API2
     
     cell_props => $cel_props
 
+=item B<cell_render_hook> - CODE reference to a function called with the current cell coordinates.  If used the parameter 'cell_render_hook' must be a function reference. It is most useful for creating a url link inside of a cell. The following example adds a link in the first column of each non-header row:
+
+    cell_render_hook  => sub {
+        my ($page, $first_row, $row, $col, $x, $y, $w, $h) = @_;
+
+        # Do nothing except for first column (and not a header row)
+        return unless ($col == 0);
+        return if ($first_row);
+
+        # Create link
+        my $value = $list_of_vals[$row-1];
+        my $url = "https://${hostname}/app/${value}";
+
+        my $annot = $page->annotation();
+        $annot->url( $url, -rect => [$x, $y, $x+$w, $y+$h] );
+    },
+    
 =back
 
 =head4 Header Row Properties
 
-If the 'header_props' parameter is used, it should be a hashref. Passing an empty HASH will triger a header row initialised with Default values.
+If the 'header_props' parameter is used, it should be a hashref. Passing an empty HASH will trigger a header row initialised with Default values.
 There is no 'data' variable for the content, because the module asumes that first table row will become the header row. It will copy this row and put it on every new page if 'repeat' param is set.
 
 =over
@@ -1183,10 +1262,10 @@ B<Default:> #FFFFAA
 B<Value:> 0,1   1-Yes/True, 0-No/False 
 B<Default:> 0
 
-=item B<justify> - Alignment of text in the header row
+=item B<justify> - Alignment of text in the header row.
 
 B<Value:> One of 'left', 'right', 'center'
-B<Default:> 'left'
+B<Default:> Same as column alignment (or 'left' if undefined)
 
     my $hdr_props = 
     {
